.. _api ref:

=============
API Reference
=============

The full API documentation for all classes and functions in the **smol** package are
listed below.

.. toctree::
   :maxdepth: 2

   cofe/index
   moca/index
   io
   exceptions
   constants
   utils

Autogenerated Indices
---------------------

* :ref:`modindex`
* :ref:`genindex`
